==> ejc-analysis-impl-3.0.0-20230630.095827-36-sources.jar: com/ejianc/business/analysis/bean/ProDurationDelayEntity.java <==
package com.ejianc.business.analysis.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工期延误项目成本风险化解情况
 *
 * @author generator
 *
 */
@TableName("ejc_anaylsis_project_duration_delay")
public class ProDurationDelayEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="branch_office_name")
    private String branchOfficeName; // 分公司名称
    @TableField(value="project_status")
    private Long projectStatus; // 项目状态
    @TableField(value="begin_delay_time")
    private Date beginDelayTime; // 工期延误-工期延误开始时间
    @TableField(value="end_delay_time")
    private Date endDelayTime; // 工期延误-工期延误结束时间
    @TableField(value="delay_days_total")
    private BigDecimal delayDaysTotal; // 工期延误-延误天数-延误天数合计
    @TableField(value="delay_days_casej")
    private BigDecimal delayDaysCasej; // 工期延误-延误天数-甲方原因
    @TableField(value="delay_days_casey")
    private BigDecimal delayDaysCasey; // 工期延误-延误天数-乙方原因
    @TableField(value="delay_cost_total")
    private BigDecimal delayCostTotal; // 工期延误-涉及增加的成本(万元)-增加成本合计
    @TableField(value="delay_cost_casej")
    private BigDecimal delayCostCasej; // 工期延误-涉及增加的成本(万元)-甲方原因
    @TableField(value="delay_cost_casey")
    private BigDecimal delayCostCasey; // 工期延误-涉及增加的成本(万元)-乙方原因
    @TableField(value="delay_claim_estimate")
    private BigDecimal delayClaimEstimate; // 工期延误-预计索赔-预计工期索赔
    @TableField(value="delay_claim_basis")
    private BigDecimal delayClaimBasis; // 工期延误-预计索赔-有依有据索赔
    @TableField(value="delay_claim_time")
    private Date delayClaimTime; // 工期延误-预计索赔-预计报出时间
    @TableField(value="compensate_date")
    private BigDecimal compensateDate; // 向甲方提出索赔-索赔工期(天)
    @TableField(value="compensate_cost")
    private BigDecimal compensateCost; // 向甲方提出索赔-索赔费用(万元)
    @TableField(value="compensate_submit")
    private Date compensateSubmit; // 向甲方提出索赔-提交索赔时间
    @TableField(value="compensate_confirm")
    private Integer compensateConfirm; // 向甲方提出索赔-是否确认
    @TableField(value="compensate_confirm_days")
    private BigDecimal compensateConfirmDays; // 向甲方提出索赔-甲方确认-天数
    @TableField(value="compensate_confirm_date")
    private Date compensateConfirmDate; // 向甲方提出索赔-甲方确认-日期
    @TableField(value="compensate_confirm_cost")
    private BigDecimal compensateConfirmCost; // 向甲方提出索赔-甲方确认-赔偿(索赔)金额(万元)
    @TableField(value="project_completion_days")
    private BigDecimal projectCompletionDays; // 项目完工-预计工期延误总天数
    @TableField(value="project_completion_cost")
    private BigDecimal projectCompletionCost; // 项目完工-预计因工期延误发生的总成本
    @TableField(value="person_liable")
    private String personLiable; // 责任人
    @TableField(value="estimated_completion_time")
    private Date estimatedCompletionTime; // 预计完成时间
    @TableField(value="resolution_measures")
    private String resolutionMeasures; // 化解措施
    @TableField(value="remarks")
    private String remarks; // 备注
    @TableField(value="month")
    private Date month; // 月份
    @TableField(value="reporting_month")
    private Date reportingMonth; // 报表日期
    @TableField(value="two_org_id")
    private Long twoOrgId; // 二级组织id
    @TableField(value="two_org_code")
    private String twoOrgCode; // 二级组织编码
    @TableField(value="two_org_name")
    private String twoOrgName; // 二级组织名称




    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getBranchOfficeName() {
        return branchOfficeName;
    }

    public void setBranchOfficeName(String branchOfficeName) {
        this.branchOfficeName = branchOfficeName;
    }
    public Long getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Long projectStatus) {
        this.projectStatus = projectStatus;
    }
    public Date getBeginDelayTime() {
        return beginDelayTime;
    }

    public void setBeginDelayTime(Date beginDelayTime) {
        this.beginDelayTime = beginDelayTime;
    }
    public Date getEndDelayTime() {
        return endDelayTime;
    }

    public void setEndDelayTime(Date endDelayTime) {
        this.endDelayTime = endDelayTime;
    }
    public BigDecimal getDelayDaysTotal() {
        return delayDaysTotal;
    }

    public void setDelayDaysTotal(BigDecimal delayDaysTotal) {
        this.delayDaysTotal = delayDaysTotal;
    }
    public BigDecimal getDelayDaysCasej() {
        return delayDaysCasej;
    }

    public void setDelayDaysCasej(BigDecimal delayDaysCasej) {
        this.delayDaysCasej = delayDaysCasej;
    }
    public BigDecimal getDelayDaysCasey() {
        return delayDaysCasey;
    }

    public void setDelayDaysCasey(BigDecimal delayDaysCasey) {
        this.delayDaysCasey = delayDaysCasey;
    }
    public BigDecimal getDelayCostTotal() {
        return delayCostTotal;
    }

    public void setDelayCostTotal(BigDecimal delayCostTotal) {
        this.delayCostTotal = delayCostTotal;
    }
    public BigDecimal getDelayCostCasej() {
        return delayCostCasej;
    }

    public void setDelayCostCasej(BigDecimal delayCostCasej) {
        this.delayCostCasej = delayCostCasej;
    }
    public BigDecimal getDelayCostCasey() {
        return delayCostCasey;
    }

    public void setDelayCostCasey(BigDecimal delayCostCasey) {
        this.delayCostCasey = delayCostCasey;
    }
    public BigDecimal getDelayClaimEstimate() {
        return delayClaimEstimate;
    }

    public void setDelayClaimEstimate(BigDecimal delayClaimEstimate) {
        this.delayClaimEstimate = delayClaimEstimate;
    }
    public BigDecimal getDelayClaimBasis() {
        return delayClaimBasis;
    }

    public void setDelayClaimBasis(BigDecimal delayClaimBasis) {
        this.delayClaimBasis = delayClaimBasis;
    }
    public Date getDelayClaimTime() {
        return delayClaimTime;
    }

    public void setDelayClaimTime(Date delayClaimTime) {
        this.delayClaimTime = delayClaimTime;
    }
    public BigDecimal getCompensateDate() {
        return compensateDate;
    }

    public void setCompensateDate(BigDecimal compensateDate) {
        this.compensateDate = compensateDate;
    }
    public BigDecimal getCompensateCost() {
        return compensateCost;
    }

    public void setCompensateCost(BigDecimal compensateCost) {
        this.compensateCost = compensateCost;
    }
    public Date getCompensateSubmit() {
        return compensateSubmit;
    }

    public void setCompensateSubmit(Date compensateSubmit) {
        this.compensateSubmit = compensateSubmit;
    }
    public Integer getCompensateConfirm() {
        return compensateConfirm;
    }

    public void setCompensateConfirm(Integer compensateConfirm) {
        this.compensateConfirm = compensateConfirm;
    }
    public BigDecimal getCompensateConfirmDays() {
        return compensateConfirmDays;
    }

    public void setCompensateConfirmDays(BigDecimal compensateConfirmDays) {
        this.compensateConfirmDays = compensateConfirmDays;
    }
    public Date getCompensateConfirmDate() {
        return compensateConfirmDate;
    }

    public void setCompensateConfirmDate(Date compensateConfirmDate) {
        this.compensateConfirmDate = compensateConfirmDate;
    }
    public BigDecimal getCompensateConfirmCost() {
        return compensateConfirmCost;
    }

    public void setCompensateConfirmCost(BigDecimal compensateConfirmCost) {
        this.compensateConfirmCost = compensateConfirmCost;
    }
    public BigDecimal getProjectCompletionDays() {
        return projectCompletionDays;
    }

    public void setProjectCompletionDays(BigDecimal projectCompletionDays) {
        this.projectCompletionDays = projectCompletionDays;
    }
    public BigDecimal getProjectCompletionCost() {
        return projectCompletionCost;
    }

    public void setProjectCompletionCost(BigDecimal projectCompletionCost) {
        this.projectCompletionCost = projectCompletionCost;
    }
    public String getPersonLiable() {
        return personLiable;
    }

    public void setPersonLiable(String personLiable) {
        this.personLiable = personLiable;
    }
    public Date getEstimatedCompletionTime() {
        return estimatedCompletionTime;
    }

    public void setEstimatedCompletionTime(Date estimatedCompletionTime) {
        this.estimatedCompletionTime = estimatedCompletionTime;
    }
    public String getResolutionMeasures() {
        return resolutionMeasures;
    }

    public void setResolutionMeasures(String resolutionMeasures) {
        this.resolutionMeasures = resolutionMeasures;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public Date getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(Date reportingMonth) {
        this.reportingMonth = reportingMonth;
    }

    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }

    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }

    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
}

==> ejc-analysis-impl-3.0.0-20230711.032208-47-sources.jar: com/ejianc/business/analysis/bean/ProDurationDelayEntity.java <==
package com.ejianc.business.analysis.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工期延误项目成本风险化解情况
 *
 * @author generator
 *
 */
@TableName("ejc_anaylsis_project_duration_delay")
public class ProDurationDelayEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="create_user_name")
    private String createUserName; // 创建人名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="project_status")
    private Long projectStatus; // 项目状态
    @TableField(value="begin_delay_time")
    private Date beginDelayTime; // 工期延误-工期延误开始时间
    @TableField(value="end_delay_time")
    private Date endDelayTime; // 工期延误-工期延误结束时间
    @TableField(value="delay_days_total")
    private BigDecimal delayDaysTotal; // 工期延误-延误天数-延误天数合计
    @TableField(value="delay_days_casej")
    private BigDecimal delayDaysCasej; // 工期延误-延误天数-甲方原因
    @TableField(value="delay_days_casey")
    private BigDecimal delayDaysCasey; // 工期延误-延误天数-乙方原因
    @TableField(value="delay_cost_total")
    private BigDecimal delayCostTotal; // 工期延误-涉及增加的成本(万元)-增加成本合计
    @TableField(value="delay_cost_casej")
    private BigDecimal delayCostCasej; // 工期延误-涉及增加的成本(万元)-甲方原因
    @TableField(value="delay_cost_casey")
    private BigDecimal delayCostCasey; // 工期延误-涉及增加的成本(万元)-乙方原因
    @TableField(value="delay_claim_estimate")
    private BigDecimal delayClaimEstimate; // 工期延误-预计索赔-预计工期索赔
    @TableField(value="delay_claim_basis")
    private BigDecimal delayClaimBasis; // 工期延误-预计索赔-有依有据索赔
    @TableField(value="delay_claim_time")
    private Date delayClaimTime; // 工期延误-预计索赔-预计报出时间
    @TableField(value="compensate_date")
    private BigDecimal compensateDate; // 向甲方提出索赔-索赔工期(天)
    @TableField(value="compensate_cost")
    private BigDecimal compensateCost; // 向甲方提出索赔-索赔费用(万元)
    @TableField(value="compensate_submit")
    private Date compensateSubmit; // 向甲方提出索赔-提交索赔时间
    @TableField(value="compensate_confirm_days")
    private BigDecimal compensateConfirmDays; // 向甲方提出索赔-甲方确认-天数
    @TableField(value="compensate_confirm_date")
    private Date compensateConfirmDate; // 向甲方提出索赔-甲方确认-日期
    @TableField(value="compensate_confirm_cost")
    private BigDecimal compensateConfirmCost; // 向甲方提出索赔-甲方确认-赔偿(索赔)金额(万元)
    @TableField(value="project_completion_days")
    private BigDecimal projectCompletionDays; // 项目完工-预计工期延误总天数
    @TableField(value="project_completion_cost")
    private BigDecimal projectCompletionCost; // 项目完工-预计因工期延误发生的总成本
    @TableField(value="person_liable")
    private String personLiable; // 责任人
    @TableField(value="estimated_completion_time")
    private Date estimatedCompletionTime; // 预计完成时间
    @TableField(value="resolution_measures")
    private String resolutionMeasures; // 化解措施
    @TableField(value="remarks")
    private String remarks; // 备注
    @TableField(value="month")
    private Date month; // 月份
    @TableField(value="reporting_month")
    private String reportingMonth; // 报表日期
    @TableField(value="two_org_id")
    private Long twoOrgId; // 二级组织id
    @TableField(value="two_org_code")
    private String twoOrgCode; // 二级组织编码
    @TableField(value="two_org_name")
    private String twoOrgName; // 二级组织名称
    @TableField(value="project_create_time")
    private Date projectCreateTime; // 项目创建日期
    @TableField(value="org_status_order")
    private Integer orgStatusOrder; // 二级组织排序



    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Long projectStatus) {
        this.projectStatus = projectStatus;
    }
    public Date getBeginDelayTime() {
        return beginDelayTime;
    }

    public void setBeginDelayTime(Date beginDelayTime) {
        this.beginDelayTime = beginDelayTime;
    }
    public Date getEndDelayTime() {
        return endDelayTime;
    }

    public void setEndDelayTime(Date endDelayTime) {
        this.endDelayTime = endDelayTime;
    }
    public BigDecimal getDelayDaysTotal() {
        return delayDaysTotal;
    }

    public void setDelayDaysTotal(BigDecimal delayDaysTotal) {
        this.delayDaysTotal = delayDaysTotal;
    }
    public BigDecimal getDelayDaysCasej() {
        return delayDaysCasej;
    }

    public void setDelayDaysCasej(BigDecimal delayDaysCasej) {
        this.delayDaysCasej = delayDaysCasej;
    }
    public BigDecimal getDelayDaysCasey() {
        return delayDaysCasey;
    }

    public void setDelayDaysCasey(BigDecimal delayDaysCasey) {
        this.delayDaysCasey = delayDaysCasey;
    }
    public BigDecimal getDelayCostTotal() {
        return delayCostTotal;
    }

    public void setDelayCostTotal(BigDecimal delayCostTotal) {
        this.delayCostTotal = delayCostTotal;
    }
    public BigDecimal getDelayCostCasej() {
        return delayCostCasej;
    }

    public void setDelayCostCasej(BigDecimal delayCostCasej) {
        this.delayCostCasej = delayCostCasej;
    }
    public BigDecimal getDelayCostCasey() {
        return delayCostCasey;
    }

    public void setDelayCostCasey(BigDecimal delayCostCasey) {
        this.delayCostCasey = delayCostCasey;
    }
    public BigDecimal getDelayClaimEstimate() {
        return delayClaimEstimate;
    }

    public void setDelayClaimEstimate(BigDecimal delayClaimEstimate) {
        this.delayClaimEstimate = delayClaimEstimate;
    }
    public BigDecimal getDelayClaimBasis() {
        return delayClaimBasis;
    }

    public void setDelayClaimBasis(BigDecimal delayClaimBasis) {
        this.delayClaimBasis = delayClaimBasis;
    }
    public Date getDelayClaimTime() {
        return delayClaimTime;
    }

    public void setDelayClaimTime(Date delayClaimTime) {
        this.delayClaimTime = delayClaimTime;
    }
    public BigDecimal getCompensateDate() {
        return compensateDate;
    }

    public void setCompensateDate(BigDecimal compensateDate) {
        this.compensateDate = compensateDate;
    }
    public BigDecimal getCompensateCost() {
        return compensateCost;
    }

    public void setCompensateCost(BigDecimal compensateCost) {
        this.compensateCost = compensateCost;
    }
    public Date getCompensateSubmit() {
        return compensateSubmit;
    }

    public void setCompensateSubmit(Date compensateSubmit) {
        this.compensateSubmit = compensateSubmit;
    }
    public BigDecimal getCompensateConfirmDays() {
        return compensateConfirmDays;
    }

    public void setCompensateConfirmDays(BigDecimal compensateConfirmDays) {
        this.compensateConfirmDays = compensateConfirmDays;
    }
    public Date getCompensateConfirmDate() {
        return compensateConfirmDate;
    }

    public void setCompensateConfirmDate(Date compensateConfirmDate) {
        this.compensateConfirmDate = compensateConfirmDate;
    }
    public BigDecimal getCompensateConfirmCost() {
        return compensateConfirmCost;
    }

    public void setCompensateConfirmCost(BigDecimal compensateConfirmCost) {
        this.compensateConfirmCost = compensateConfirmCost;
    }
    public BigDecimal getProjectCompletionDays() {
        return projectCompletionDays;
    }

    public void setProjectCompletionDays(BigDecimal projectCompletionDays) {
        this.projectCompletionDays = projectCompletionDays;
    }
    public BigDecimal getProjectCompletionCost() {
        return projectCompletionCost;
    }

    public void setProjectCompletionCost(BigDecimal projectCompletionCost) {
        this.projectCompletionCost = projectCompletionCost;
    }
    public String getPersonLiable() {
        return personLiable;
    }

    public void setPersonLiable(String personLiable) {
        this.personLiable = personLiable;
    }
    public Date getEstimatedCompletionTime() {
        return estimatedCompletionTime;
    }

    public void setEstimatedCompletionTime(Date estimatedCompletionTime) {
        this.estimatedCompletionTime = estimatedCompletionTime;
    }
    public String getResolutionMeasures() {
        return resolutionMeasures;
    }

    public void setResolutionMeasures(String resolutionMeasures) {
        this.resolutionMeasures = resolutionMeasures;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }

    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }

    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }

    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }

    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }

    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }
}
